function S = billboard( Nx, Ny )
%BILLBOARD Return the billboard array
%
%	Written by Chun-Lin Liu
%	E-mail : cl.liu@caltech.edu
%	Project website:
%	https://systems.caltech.edu/dsp/students/clliu/hourglass.html
%	Last revised on July 31, 2017
%
%   If you use this script, please cite reference [1] and [2].
%
%	Reference
%   [1] C.-L. Liu and P. P. Vaidyanathan, “Two-Dimensional Sparse Arrays with Hole-Free Coarray and Reduced Mutual Coupling,” in Proc. of the 50th Asilomar Conference on Signals, Systems, and Computers, Pacific Grove, CA, Nov. 2016.
%   [2] C.-L. Liu and P. P. Vaidyanathan, “Hourglass Arrays, and Other Novel 2D Sparse Arrays with Reduced Mutual Coupling,” IEEE Transactions on Signal Processing, vol. 65, no. 13, pp. 3369-3383, July 2017.
%
%
%   Input: Nx and Ny. Please see [1, Fig. 1(b)] or [2, Fig. 2(b)].
%   Output: An integer matrix S. The first column S(:,1) contains all the x
%   coordinates while the second column S(:,2) has all the y coordinates.

if (nargin == 1)
    Ny = Nx;
end

if ( Nx == Ny && Nx >= 3 )
    S = [0, 0;
        zeros(Nx-1, 1), (1 : Nx-1).'; ...
        (1:Nx-1).', zeros(Nx-1, 1); ...
        (2:Nx-1).', (2:Nx-1).'];
else
    P = min(Nx, Ny) - 1;
    S = [0, 0;
        zeros(Ny-1, 1), (1 : Ny-1).'; ...
        (1:Nx-1).', zeros(Nx-1, 1); ...
        (Nx-1) - (0:P-1).', (Ny-1) - (0:P-1).'];
end


end

