function S = uniform_rectangular_arrays( Nx, Ny )
% Uniform_Rectangular_Arrays: Return the URA configuration 
%
%	Written by Chun-Lin Liu
%	E-mail : cl.liu@caltech.edu
%	Project website:
%	https://systems.caltech.edu/dsp/students/clliu/hourglass.html
%	Last revised on July 31, 2017
%
%   If you use this script, please cite reference [1] and [2].
%
%	Reference
%   [1] C.-L. Liu and P. P. Vaidyanathan, “Two-Dimensional Sparse Arrays with Hole-Free Coarray and Reduced Mutual Coupling,” in Proc. of the 50th Asilomar Conference on Signals, Systems, and Computers, Pacific Grove, CA, Nov. 2016.
%   [2] C.-L. Liu and P. P. Vaidyanathan, “Hourglass Arrays, and Other Novel 2D Sparse Arrays with Reduced Mutual Coupling,” IEEE Transactions on Signal Processing, vol. 65, no. 13, pp. 3369-3383, July 2017.
%
%
%   Input: Nx and Ny. Please see [1, Fig. 1(a)] or [2, Fig. 2(a)].
%   Output: An integer matrix S. The first column S(:,1) contains all the x
%   coordinates while the second column S(:,2) has all the y coordinates.

if (nargin == 1)
    Ny = Nx;
end

[SS, SS_] = ndgrid(0:Nx-1, 0:Ny-1);

S = [SS(:), SS_(:)];

end

